==> codepost-0.1.6.tar.gz: codepost-0.1.6/README.md <==
# codePost API Python Library

[![Build Status](https://travis-ci.com/codepost-io/codePost-python.svg?branch=master)](https://travis-ci.com/codepost-io/codePost-python?branch=master)

This package provides a Python library to conveniently access the codePost API
from any application or script written in the Python language.

<!--

[![Coverage Status](https://coveralls.io/repos/github/codepost-io/codePost-api-python/badge.svg?branch=master)](https://coveralls.io/github/codepost-io/codePost-api-python?branch=master)

The package provides a set of helper functions used to access the codePost API from applications written in the Python language.

## Documentation

This library implements helper methods to access the codePost API. Check out the [Python version of the codePost API docs](http://docs.codepost.io/?python#introduction).

## Installation

The recommended method to install this codePost API Python library, is to use pip:

```
pip install codePost-api
```

or for local development:

```
pip install --user codePost-api
```

## Usage

To use the functions available in this library, you must have a codePost API key. As of March 2019, to retrieve a codePost API key, you must be a administrator of a course on codePost. It will then be accessible from [https://codepost.io/settings](https://codepost.io/settings).

## Development

To start developing, install [pipenv](https://github.com/pypa/pipenv), then install all dependencies for this project:

    pipenv install --dev

Run all tests on all supported versions of Python which you have locally installed:

    make test

Run all tests for a specific Python version (modify `-e` according to your Python target):

    pipenv run tox -e py27

Run all tests in a single file for a specific Python version:

    pipenv run tox -e py27 -- tests/test_helpers.py

-->

==> codepost-0.2.23.tar.gz: codepost-0.2.23/README.md <==
# codePost API Python Library

[![Build Status](https://travis-ci.com/codepost-io/codePost-python.svg?branch=master)](https://travis-ci.com/codepost-io/codePost-python?branch=master)
[![Coverage Status](https://coveralls.io/repos/github/codepost-io/codePost-python/badge.svg?branch=master)](https://coveralls.io/github/codepost-io/codepost-python?branch=master)

This package provides a Python library to conveniently access the codePost API
from any application or script written in the Python language. To learn more, check out the [codePost website](https://codepost.io). 

<!--

[![Coverage Status](https://coveralls.io/repos/github/codepost-io/codePost-api-python/badge.svg?branch=master)](https://coveralls.io/github/codepost-io/codePost-api-python?branch=master)

The package provides a set of helper functions used to access the codePost API from applications written in the Python language.

## Documentation

This library implements helper methods to access the codePost API. Check out the [Python version of the codePost API docs](http://docs.codepost.io/?python#introduction).

## Installation

The recommended method to install this codePost API Python library, is to use pip:

```
pip install codePost-api
```

or for local development:

```
pip install --user codePost-api
```

## Usage

To use the functions available in this library, you must have a codePost API key. As of March 2019, to retrieve a codePost API key, you must be a administrator of a course on codePost. It will then be accessible from [https://codepost.io/settings](https://codepost.io/settings).

## Development

To start developing, install [pipenv](https://github.com/pypa/pipenv), then install all dependencies for this project:

    pipenv install --dev

Run all tests on all supported versions of Python which you have locally installed:

    make test

Run all tests for a specific Python version (modify `-e` according to your Python target):

    pipenv run tox -e py27

Run all tests in a single file for a specific Python version:

    pipenv run tox -e py27 -- tests/test_helpers.py

-->
